aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_conversations.h
diff options
context:
space:
mode:
authorPaul Gilbert2016-04-28 19:43:55 -0400
committerPaul Gilbert2016-07-10 16:22:34 -0400
commitde7329619612514e8fd3e9ba1f3e6d7389fd199d (patch)
tree0c99572f4106b572859e73df502b8f2fcacf0e2a /engines/titanic/pet_control/pet_conversations.h
parentb7ad513b0f0c99bc670546dbb3483e93d59652ee (diff)
downloadscummvm-rg350-de7329619612514e8fd3e9ba1f3e6d7389fd199d.tar.gz
scummvm-rg350-de7329619612514e8fd3e9ba1f3e6d7389fd199d.tar.bz2
scummvm-rg350-de7329619612514e8fd3e9ba1f3e6d7389fd199d.zip
TITANIC: Implement PET Text scrollToBottom, beginnings of addLine
Diffstat (limited to 'engines/titanic/pet_control/pet_conversations.h')
-rw-r--r--engines/titanic/pet_control/pet_conversations.h26
1 files changed, 22 insertions, 4 deletions
diff --git a/engines/titanic/pet_control/pet_conversations.h b/engines/titanic/pet_control/pet_conversations.h
index 8a3ca886a5..d04e9834d1 100644
--- a/engines/titanic/pet_control/pet_conversations.h
+++ b/engines/titanic/pet_control/pet_conversations.h
@@ -29,6 +29,8 @@
namespace Titanic {
+enum SummonResult { SUMMON_CANT = 0, SUMMON_CAN = 1, SUMMON_ABORT = 2 };
+
class CPetConversations : public CPetSection {
private:
CPetGfxElement _scrollUp;
@@ -39,8 +41,8 @@ private:
CPetGfxElement _val5;
CPetGfxElement _val6;
int _field14C;
- CPetGfxElement _val7;
- CPetGfxElement _val8;
+ CPetGfxElement _doorBot;
+ CPetGfxElement _bellBot;
CPetGfxElement _val9;
CPetGfxElement _valArray2[9];
int _field30C;
@@ -57,14 +59,29 @@ private:
bool setupControl(CPetControl *petControl);
/**
+ * Scroll up the conversation log
+ */
+ void scrollUp();
+
+ /**
* Scroll down the conversation log
*/
void scrollDown();
/**
* Scroll up the conversation log
*/
- void scrollUp();
+ void scrollToBottom();
+
+ /**
+ * Check whether an NPC can be summoned
+ */
+ SummonResult canSummonNPC(const CString &name);
+
+ /**
+ * Summon an NPC
+ */
+ void summonNPC(const CString &name);
public:
CPetConversations();
@@ -88,6 +105,7 @@ public:
* pass onto the currently active section/area
*/
virtual bool MouseButtonDownMsg(CMouseButtonDownMsg *msg);
+ virtual bool MouseButtonUpMsg(CMouseButtonUpMsg *msg);
};
} // End of namespace Titanic
@@ -57,14 +59,29 @@ private:
void scrollDown();
/**
- * Scroll up the conversation log
+ * Scroll to the bottom of the conversation log
*/